@@ -1,3 +1,3 @@
-from .pspnet import PSPNet
 from .ses import BertForSES
-from .semantic_segmentation import ModelBuilder, SegmentationModule
\ No newline at end of file
+from .semantic_segmentation import ModelBuilder, SegmentationModule
+from .object_detection import Detect, Model
\ No newline at end of file
